import sys,os
sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
from ugot.grpc_pb import device_pb2,device_pb2_grpc
from base_client import GrpcClient

class DeviceClient(GrpcClient):
    def __init__(self, address):
        super().__init__(address)

        self.client = device_pb2_grpc.DeviceServiceGrpcStub(channel=self.channel)

    """ 显示屏 """
    def display_background(self, color):
        input_data = device_pb2.DisplayUIRequest()
        input_data.background_color = color  # "FFFF0000"

        response = self.client.setDisplayUI(input_data)
        return response

    def print_text(self, text, color):
        input_data = device_pb2.DisplayUIRequest()
        # input_data.background_color = "FF000000"
        text_info = input_data.text_list.add()
        text_info.text = str(text)
        text_info.font_color = color
        text_info.font_size = 16

        response = self.client.setDisplayUI(input_data)
        return response

    def print_text_newline(self, text, color):
        input_data = device_pb2.DisplayUIRequest()
        # input_data.background_color = "FF00FF00"
        text_info = input_data.text_list.add()
        text_info.text = str(text)
        text_info.font_color = color
        text_info.font_size = 16
        text_info.newline = True

        response = self.client.setDisplayUI(input_data)
        return response

    def display_image(self, image_name):
        input_data = device_pb2.DisplayUIRequest()
        input_data.img_name = image_name

        response = self.client.setDisplayUI(input_data)
        return response

    def clear_screen(self):
        input_data = device_pb2.DisplayUIRequest()
        input_data.reset = True

        response = self.client.setDisplayUI(input_data)
        return response

    """ 灯效 """
    def showLightEffect(self, color, effect, level=2):
        input_data = device_pb2.LightEffectRequest()
        input_data.effect = effect
        input_data.color = color
        input_data.level = level

        response = self.client.showLightEffect(input_data)
        return response

    def showLightColor(self, top_light_color=-1, left_light_color=-1, right_light_color=-1, down_light_color=-1):

        input_data = device_pb2.LightColorRequest()
        input_data.top_light = top_light_color
        input_data.left_light = left_light_color
        input_data.right_light = right_light_color
        input_data.down_light = down_light_color

        response = self.client.showLightColor(input_data)
        return response

    def turnOffLight(self, lights):
        input_data = device_pb2.TurnOffLightRequest()
        ids = []
        if isinstance(lights, list):
            ids += lights
        elif isinstance(lights, int):
            ids.append(lights)
        for item in ids:
            input_data.lights.append(item)

        response = self.client.showLightEffect(input_data)
        return response

    def turnOffAllLights(self):
        input_data = device_pb2.LightEffectRequest()
        input_data.effect = 1
        input_data.color = 0
        input_data.level = 2

        response = self.client.showLightEffect(input_data)
        return response

    def setVolume(self, volume):
        input_data = device_pb2.SetVolumeRequest()
        input_data.volume = volume

        response = self.client.setVolume(input_data)
        return response

    def getVolume(self):
        input_data = device_pb2.GetVolumeRequest()

        response = self.client.getVolume(input_data)
        return response

    def getMacAddress(self):
        input_data = device_pb2.MacAddressRequest()

        response = self.client.getMacAddress(input_data)
        return response

    def getDeviceList(self):
        input_data = device_pb2.DeviceListRequest()

        response = self.client.getDeviceList(input_data)
        return response

    def __del__(self):
        # # 销毁时候停止灯光
        try:
            self.turnOffAllLights()
        except Exception as e:
            print('device turnOffAllLights error:')



import sys,os
sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
from ugot.grpc_pb import model_pb2,model_pb2_grpc
from base_client import GrpcClient

MODEL_TYPE_MECANUM = 'mecanum'
MODEL_TYPE_BALANCE = 'balance'
MODEL_TYPE_TRANSFORM = 'transform'

class ModelClient(GrpcClient):
    def __init__(self, address):
        super().__init__(address)

        self.client = model_pb2_grpc.ModelServiceGrpcStub(channel=self.channel)
        # 舵机
        pass

    def model_move_control(self, linear_speed=0, direction=0, rotate_speed=0, time=0, mileage=0, target_angle=0,
                           model_type='', client_type=0):
        """ 模型通用运动控制接口
        """

        # print('received model_move_control parameters {} {} {} {} {} {}'.format(linear_speed, direction, rotate_speed, time, mileage, target_angle))

        input_data = model_pb2.ModelControlRequest()
        input_data.type = model_type
        input_data.client_type = client_type  # 1表示手柄操作

        input_data.params.linear_speed = linear_speed
        input_data.params.direction = direction
        input_data.params.rotate_speed = rotate_speed
        input_data.params.time = time
        input_data.params.mileage = mileage
        input_data.params.target_angle = target_angle

        response = self.client.modelCommonControl(input_data)
        return response

    def mecanum_move_control(self, linear_speed=0, direction=0, rotate_speed=0, time=0, mileage=0, target_angle=0,
                               client_type=0):
        """ 麦轮车通用控制
        """

        response = self.model_move_control(linear_speed, direction, rotate_speed, time, mileage, target_angle,
                                            model_type=MODEL_TYPE_MECANUM, client_type=client_type)
        return response

    def mecanum_stop(self):
        """ 小车停止
        """
        input_data = model_pb2.MecanumStopRequest()

        input_data.type = MODEL_TYPE_MECANUM

        response = self.client.mecanumStop(input_data)
        return response

    def mecanum_motor_control(self, lf, rf, lb, rb):
        """ 变形工程车电机控制
        """
        input_data = model_pb2.MotorControlRequest()

        input_data.type = MODEL_TYPE_MECANUM

        input_data.params.lf_joint = lf
        input_data.params.rf_joint = rf
        input_data.params.lb_joint = lb
        input_data.params.rb_joint = rb

        response = self.client.mecanumMotorControl(input_data)
        return response

    def mecanum_xyz_control(self, speed_x, speed_y, speed_z):
        """ 麦轮车xyz控制
        """
        input_data = model_pb2.XYZControlRequest()

        input_data.type = MODEL_TYPE_MECANUM

        input_data.params.linear_x = speed_x
        input_data.params.linear_y = speed_y
        input_data.params.angle_z = speed_z

        response = self.client.mecanumXYZControl(input_data)
        return response

    def transform_move_control(self, linear_speed=0, direction=0, rotate_speed=0, time=0, mileage=0, target_angle=0,
                               client_type=0):
        """ 变形工程车通用控制
        """

        response = self.model_move_control(linear_speed, direction, rotate_speed, time, mileage, target_angle,
                                            model_type=MODEL_TYPE_TRANSFORM, client_type=client_type)
        return response

    def transform_motor_control(self, lf, rf, lb, rb):
        """ 变形工程车电机控制
        """
        input_data = model_pb2.MotorControlRequest()

        input_data.type = MODEL_TYPE_TRANSFORM

        input_data.params.lf_joint = lf
        input_data.params.rf_joint = rf
        input_data.params.lb_joint = lb
        input_data.params.rb_joint = rb

        response = self.client.mecanumMotorControl(input_data)
        return response

    def transform_stop(self):
        """ 小车停止
        """
        input_data = model_pb2.MecanumStopRequest()

        input_data.type = MODEL_TYPE_TRANSFORM

        response = self.client.mecanumStop(input_data)
        return response

    def transform_arm_control(self, joint, position, time):
        input_data = model_pb2.TransformArmsControlRequest()

        input_data.type = MODEL_TYPE_TRANSFORM

        input_data.params.joint = joint
        input_data.params.position = position
        input_data.params.time = int(time / 20)

        response = self.client.transformArmsControl(input_data)
        return response

    def transform_set_height(self, height):
        input_data = model_pb2.TransformSetHeightRequest()

        input_data.type = MODEL_TYPE_TRANSFORM

        input_data.params.height = height

        response = self.client.transformSetHeight(input_data)
        return response

    def transform_adaption(self, enable):
        input_data = model_pb2.EnableAdaptivePoseRequest()

        input_data.type = MODEL_TYPE_TRANSFORM

        input_data.params.enable = enable

        response = self.client.enableAdaptivePose(input_data)
        return response

    def transform_set_height_by_increment(self, increment):
        input_data = model_pb2.TransformSetHeightIncrementRequest()

        input_data.type = MODEL_TYPE_TRANSFORM
        input_data.client_type = 1  # 1表示手柄操作

        input_data.params.increment = increment

        response = self.client.transformSetHeightByIncrement(input_data)
        return response

    def balance_move_control(self, linear_speed=0, direction=0, rotate_speed=0, time=0, mileage=0, target_angle=0,
                             client_type=0):
        """ 平衡车通用控制
        """

        response = self.model_move_control(linear_speed, direction, rotate_speed, time, mileage, target_angle,
                                            model_type=MODEL_TYPE_BALANCE, client_type=client_type)
        return response

    def balance_keep_balancing(self, start, keep_balance=True):
        """启动小车并保持自平衡
        """
        input_data = model_pb2.BalanceKeepBalancingRequest()
        input_data.type = MODEL_TYPE_BALANCE

        input_data.params.start = start
        input_data.params.keep_balance = keep_balance

        response = self.client.balanceKeepBalancing(input_data)
        return response

    def setAcceleration(self, type, linear_x=0.0, linear_y=0.0, linear_z=0.0, angular_x=0.0, angular_y=0.0, augular_z=0.0):
        """设置加速度通用接口
        """
        input_data = model_pb2.SetAccelerationRequest()

        input_data.type = type

        input_data.params.linear_x = linear_x
        input_data.params.linear_y = linear_y
        input_data.params.linear_z = linear_x
        input_data.params.angular_x = angular_x
        input_data.params.angular_y = angular_y
        input_data.params.angular_z = augular_z

        response = self.client.setAcceleration(input_data)
        return response

    def setBalanceAcceleration(self, linear_x=0.0):
        """设置平衡车加速度
        """
        input_data = model_pb2.SetAccelerationRequest()

        input_data.type = MODEL_TYPE_BALANCE

        input_data.params.linear_x = linear_x
        input_data.params.linear_y = 0
        input_data.params.linear_z = 0
        input_data.params.angular_x = 0
        input_data.params.angular_y = 0
        input_data.params.angular_z = 8

        response = self.client.setAcceleration(input_data)
        return response

    def resetAcceleration(self, type):
        """重置加速度
        """
        input_data = model_pb2.ResetAccelerationRequest()

        input_data.type = type # type=all表示不区分模型

        response = self.client.resetAcceleration(input_data)
        return response

    def stopAllModels(self):
        input_data = model_pb2.MecanumStopRequest()

        input_data.type = 'all'

        response = self.client.mecanumStop(input_data)
        return response
    def __del__(self):
        # 销毁时候停止模型
        try:
            self.stopAllModels()
        except Exception as e:
            print('model stopAllModels error:')


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import audio_pb2 as audio__pb2


class AudioServiceGrpcStub(object):
    """定义服务,用在rpc传输中
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.setAudioAsr = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/setAudioAsr',
                request_serializer=audio__pb2.AudioAsrRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioAsrResponse.FromString,
                )
        self.setAudioTts = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/setAudioTts',
                request_serializer=audio__pb2.AudioTtsRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioCommonResponse.FromString,
                )
        self.setAudioNlp = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/setAudioNlp',
                request_serializer=audio__pb2.AudioNlpRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioNlpResponse.FromString,
                )
        self.insertAudioFile = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/insertAudioFile',
                request_serializer=audio__pb2.AudioFileRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioCommonResponse.FromString,
                )
        self.deleteAudioFile = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/deleteAudioFile',
                request_serializer=audio__pb2.AudioFileRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioCommonResponse.FromString,
                )
        self.getAudioFileList = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/getAudioFileList',
                request_serializer=audio__pb2.AudioFileListRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioFileListResponse.FromString,
                )
        self.modifyAudioFileName = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/modifyAudioFileName',
                request_serializer=audio__pb2.ModifyAudioNameRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioCommonResponse.FromString,
                )
        self.playAudioFile = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/playAudioFile',
                request_serializer=audio__pb2.AudioPlayRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioCommonResponse.FromString,
                )
        self.startRecordAudioFile = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/startRecordAudioFile',
                request_serializer=audio__pb2.AudioEmptyRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioCommonResponse.FromString,
                )
        self.stopRecordAudioFile = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/stopRecordAudioFile',
                request_serializer=audio__pb2.AudioEmptyRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioRecordResponse.FromString,
                )
        self.stopPlayAudio = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/stopPlayAudio',
                request_serializer=audio__pb2.AudioEmptyRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioCommonResponse.FromString,
                )
        self.getDirectionOfAudio = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/getDirectionOfAudio',
                request_serializer=audio__pb2.AudioDirectionRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioDirectionResponse.FromString,
                )
        self.enableAudioDirection = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/enableAudioDirection',
                request_serializer=audio__pb2.AudioEmptyRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioCommonResponse.FromString,
                )
        self.disableAudioDirection = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/disableAudioDirection',
                request_serializer=audio__pb2.AudioEmptyRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioCommonResponse.FromString,
                )
        self.getCurrentRms = channel.unary_unary(
                '/AudioPackage.AudioServiceGrpc/getCurrentRms',
                request_serializer=audio__pb2.AudioEmptyRequest.SerializeToString,
                response_deserializer=audio__pb2.AudioRmsResponse.FromString,
                )


class AudioServiceGrpcServicer(object):
    """定义服务,用在rpc传输中
    """

    def setAudioAsr(self, request, context):
        """ASR语音
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setAudioTts(self, request, context):
        """设置TTS
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setAudioNlp(self, request, context):
        """设置NLP
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def insertAudioFile(self, request, context):
        """添加音频文件到数据库
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deleteAudioFile(self, request, context):
        """删除音频文件
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAudioFileList(self, request, context):
        """获取音频列表
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def modifyAudioFileName(self, request, context):
        """修改音频名称
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def playAudioFile(self, request, context):
        """播放音频文件
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startRecordAudioFile(self, request, context):
        """开始录音
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopRecordAudioFile(self, request, context):
        """停止录音
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopPlayAudio(self, request, context):
        """停止播放音频
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getDirectionOfAudio(self, request, context):
        """获取声音方向角度
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enableAudioDirection(self, request, context):
        """开启声源定位
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disableAudioDirection(self, request, context):
        """关闭声源定位
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getCurrentRms(self, request, context):
        """获取声音响度(db)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AudioServiceGrpcServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'setAudioAsr': grpc.unary_unary_rpc_method_handler(
                    servicer.setAudioAsr,
                    request_deserializer=audio__pb2.AudioAsrRequest.FromString,
                    response_serializer=audio__pb2.AudioAsrResponse.SerializeToString,
            ),
            'setAudioTts': grpc.unary_unary_rpc_method_handler(
                    servicer.setAudioTts,
                    request_deserializer=audio__pb2.AudioTtsRequest.FromString,
                    response_serializer=audio__pb2.AudioCommonResponse.SerializeToString,
            ),
            'setAudioNlp': grpc.unary_unary_rpc_method_handler(
                    servicer.setAudioNlp,
                    request_deserializer=audio__pb2.AudioNlpRequest.FromString,
                    response_serializer=audio__pb2.AudioNlpResponse.SerializeToString,
            ),
            'insertAudioFile': grpc.unary_unary_rpc_method_handler(
                    servicer.insertAudioFile,
                    request_deserializer=audio__pb2.AudioFileRequest.FromString,
                    response_serializer=audio__pb2.AudioCommonResponse.SerializeToString,
            ),
            'deleteAudioFile': grpc.unary_unary_rpc_method_handler(
                    servicer.deleteAudioFile,
                    request_deserializer=audio__pb2.AudioFileRequest.FromString,
                    response_serializer=audio__pb2.AudioCommonResponse.SerializeToString,
            ),
            'getAudioFileList': grpc.unary_unary_rpc_method_handler(
                    servicer.getAudioFileList,
                    request_deserializer=audio__pb2.AudioFileListRequest.FromString,
                    response_serializer=audio__pb2.AudioFileListResponse.SerializeToString,
            ),
            'modifyAudioFileName': grpc.unary_unary_rpc_method_handler(
                    servicer.modifyAudioFileName,
                    request_deserializer=audio__pb2.ModifyAudioNameRequest.FromString,
                    response_serializer=audio__pb2.AudioCommonResponse.SerializeToString,
            ),
            'playAudioFile': grpc.unary_unary_rpc_method_handler(
                    servicer.playAudioFile,
                    request_deserializer=audio__pb2.AudioPlayRequest.FromString,
                    response_serializer=audio__pb2.AudioCommonResponse.SerializeToString,
            ),
            'startRecordAudioFile': grpc.unary_unary_rpc_method_handler(
                    servicer.startRecordAudioFile,
                    request_deserializer=audio__pb2.AudioEmptyRequest.FromString,
                    response_serializer=audio__pb2.AudioCommonResponse.SerializeToString,
            ),
            'stopRecordAudioFile': grpc.unary_unary_rpc_method_handler(
                    servicer.stopRecordAudioFile,
                    request_deserializer=audio__pb2.AudioEmptyRequest.FromString,
                    response_serializer=audio__pb2.AudioRecordResponse.SerializeToString,
            ),
            'stopPlayAudio': grpc.unary_unary_rpc_method_handler(
                    servicer.stopPlayAudio,
                    request_deserializer=audio__pb2.AudioEmptyRequest.FromString,
                    response_serializer=audio__pb2.AudioCommonResponse.SerializeToString,
            ),
            'getDirectionOfAudio': grpc.unary_unary_rpc_method_handler(
                    servicer.getDirectionOfAudio,
                    request_deserializer=audio__pb2.AudioDirectionRequest.FromString,
                    response_serializer=audio__pb2.AudioDirectionResponse.SerializeToString,
            ),
            'enableAudioDirection': grpc.unary_unary_rpc_method_handler(
                    servicer.enableAudioDirection,
                    request_deserializer=audio__pb2.AudioEmptyRequest.FromString,
                    response_serializer=audio__pb2.AudioCommonResponse.SerializeToString,
            ),
            'disableAudioDirection': grpc.unary_unary_rpc_method_handler(
                    servicer.disableAudioDirection,
                    request_deserializer=audio__pb2.AudioEmptyRequest.FromString,
                    response_serializer=audio__pb2.AudioCommonResponse.SerializeToString,
            ),
            'getCurrentRms': grpc.unary_unary_rpc_method_handler(
                    servicer.getCurrentRms,
                    request_deserializer=audio__pb2.AudioEmptyRequest.FromString,
                    response_serializer=audio__pb2.AudioRmsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'AudioPackage.AudioServiceGrpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AudioServiceGrpc(object):
    """定义服务,用在rpc传输中
    """

    @staticmethod
    def setAudioAsr(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/setAudioAsr',
            audio__pb2.AudioAsrRequest.SerializeToString,
            audio__pb2.AudioAsrResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setAudioTts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/setAudioTts',
            audio__pb2.AudioTtsRequest.SerializeToString,
            audio__pb2.AudioCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setAudioNlp(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/setAudioNlp',
            audio__pb2.AudioNlpRequest.SerializeToString,
            audio__pb2.AudioNlpResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def insertAudioFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/insertAudioFile',
            audio__pb2.AudioFileRequest.SerializeToString,
            audio__pb2.AudioCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deleteAudioFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/deleteAudioFile',
            audio__pb2.AudioFileRequest.SerializeToString,
            audio__pb2.AudioCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getAudioFileList(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/getAudioFileList',
            audio__pb2.AudioFileListRequest.SerializeToString,
            audio__pb2.AudioFileListResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def modifyAudioFileName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/modifyAudioFileName',
            audio__pb2.ModifyAudioNameRequest.SerializeToString,
            audio__pb2.AudioCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def playAudioFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/playAudioFile',
            audio__pb2.AudioPlayRequest.SerializeToString,
            audio__pb2.AudioCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startRecordAudioFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/startRecordAudioFile',
            audio__pb2.AudioEmptyRequest.SerializeToString,
            audio__pb2.AudioCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopRecordAudioFile(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/stopRecordAudioFile',
            audio__pb2.AudioEmptyRequest.SerializeToString,
            audio__pb2.AudioRecordResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopPlayAudio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/stopPlayAudio',
            audio__pb2.AudioEmptyRequest.SerializeToString,
            audio__pb2.AudioCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getDirectionOfAudio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/getDirectionOfAudio',
            audio__pb2.AudioDirectionRequest.SerializeToString,
            audio__pb2.AudioDirectionResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enableAudioDirection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/enableAudioDirection',
            audio__pb2.AudioEmptyRequest.SerializeToString,
            audio__pb2.AudioCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disableAudioDirection(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/disableAudioDirection',
            audio__pb2.AudioEmptyRequest.SerializeToString,
            audio__pb2.AudioCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getCurrentRms(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/AudioPackage.AudioServiceGrpc/getCurrentRms',
            audio__pb2.AudioEmptyRequest.SerializeToString,
            audio__pb2.AudioRmsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import gpio_pb2 as gpio__pb2


class GpioServiceGrpcStub(object):
    """

    一: gpio 引脚对应，传值的时候转换一下

    1  146 
    2  147
    3  149 (此接口当前是 USB 供电口，不可用)
    4  150
    5  151
    6  131

    二: 引脚 PWM 输出

    frequency: 频率赫兹
    duty_cycle: slider 的值，范围（0 ～ 255）
    range: 范围，根据需求填 255

    三: 串口，开放接口上的串口默认值为：

    /dev/ttyS0

    四：串口写字符换行功能

    只要在字符串后面添加 \r\n 就能实现换行


    定义服务,用在rpc传输中
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.setGpioExport = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/setGpioExport',
                request_serializer=gpio__pb2.SetGpioExportRequest.SerializeToString,
                response_deserializer=gpio__pb2.SetGpioExportResponse.FromString,
                )
        self.readGpio = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/readGpio',
                request_serializer=gpio__pb2.ReadGpioRequest.SerializeToString,
                response_deserializer=gpio__pb2.ReadGpioResponse.FromString,
                )
        self.setGpioStartExportPwm = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/setGpioStartExportPwm',
                request_serializer=gpio__pb2.SetGpioStartExportPwmRequest.SerializeToString,
                response_deserializer=gpio__pb2.SetGpioStartExportPwmResponse.FromString,
                )
        self.setGpioStopExportPwm = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/setGpioStopExportPwm',
                request_serializer=gpio__pb2.SetGpioStopExportPwmRequest.SerializeToString,
                response_deserializer=gpio__pb2.SetGpioStopExportPwmResponse.FromString,
                )
        self.setSerbaud = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/setSerbaud',
                request_serializer=gpio__pb2.SetSerbaudRequest.SerializeToString,
                response_deserializer=gpio__pb2.SetSerbaudResponse.FromString,
                )
        self.serialExportString = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/serialExportString',
                request_serializer=gpio__pb2.SerialExportStringRequest.SerializeToString,
                response_deserializer=gpio__pb2.SerialExportStringResponse.FromString,
                )
        self.serialReadByte = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/serialReadByte',
                request_serializer=gpio__pb2.SerialReadByteRequest.SerializeToString,
                response_deserializer=gpio__pb2.SerialReadByteResponse.FromString,
                )
        self.serialReadString = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/serialReadString',
                request_serializer=gpio__pb2.SerialReadStringRequest.SerializeToString,
                response_deserializer=gpio__pb2.SerialReadStringResponse.FromString,
                )
        self.serialReadUtil = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/serialReadUtil',
                request_serializer=gpio__pb2.SerialReadUtilRequest.SerializeToString,
                response_deserializer=gpio__pb2.SerialReadUtilResponse.FromString,
                )
        self.clearAllGpioAndSerial = channel.unary_unary(
                '/GpioPackage.GpioServiceGrpc/clearAllGpioAndSerial',
                request_serializer=gpio__pb2.ClearAllGpioAndSerialRequest.SerializeToString,
                response_deserializer=gpio__pb2.ClearAllGpioAndSerialResponse.FromString,
                )


class GpioServiceGrpcServicer(object):
    """

    一: gpio 引脚对应，传值的时候转换一下

    1  146 
    2  147
    3  149 (此接口当前是 USB 供电口，不可用)
    4  150
    5  151
    6  131

    二: 引脚 PWM 输出

    frequency: 频率赫兹
    duty_cycle: slider 的值，范围（0 ～ 255）
    range: 范围，根据需求填 255

    三: 串口，开放接口上的串口默认值为：

    /dev/ttyS0

    四：串口写字符换行功能

    只要在字符串后面添加 \r\n 就能实现换行


    定义服务,用在rpc传输中
    """

    def setGpioExport(self, request, context):
        """gpio
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def readGpio(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setGpioStartExportPwm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setGpioStopExportPwm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setSerbaud(self, request, context):
        """serial
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def serialExportString(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def serialReadByte(self, request, context):
        """将数字转换成字符串发送
        rpc serialExportNum(SerialExportNumRequest) returns (SerialExportNumResponse) {};
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def serialReadString(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def serialReadUtil(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def clearAllGpioAndSerial(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GpioServiceGrpcServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'setGpioExport': grpc.unary_unary_rpc_method_handler(
                    servicer.setGpioExport,
                    request_deserializer=gpio__pb2.SetGpioExportRequest.FromString,
                    response_serializer=gpio__pb2.SetGpioExportResponse.SerializeToString,
            ),
            'readGpio': grpc.unary_unary_rpc_method_handler(
                    servicer.readGpio,
                    request_deserializer=gpio__pb2.ReadGpioRequest.FromString,
                    response_serializer=gpio__pb2.ReadGpioResponse.SerializeToString,
            ),
            'setGpioStartExportPwm': grpc.unary_unary_rpc_method_handler(
                    servicer.setGpioStartExportPwm,
                    request_deserializer=gpio__pb2.SetGpioStartExportPwmRequest.FromString,
                    response_serializer=gpio__pb2.SetGpioStartExportPwmResponse.SerializeToString,
            ),
            'setGpioStopExportPwm': grpc.unary_unary_rpc_method_handler(
                    servicer.setGpioStopExportPwm,
                    request_deserializer=gpio__pb2.SetGpioStopExportPwmRequest.FromString,
                    response_serializer=gpio__pb2.SetGpioStopExportPwmResponse.SerializeToString,
            ),
            'setSerbaud': grpc.unary_unary_rpc_method_handler(
                    servicer.setSerbaud,
                    request_deserializer=gpio__pb2.SetSerbaudRequest.FromString,
                    response_serializer=gpio__pb2.SetSerbaudResponse.SerializeToString,
            ),
            'serialExportString': grpc.unary_unary_rpc_method_handler(
                    servicer.serialExportString,
                    request_deserializer=gpio__pb2.SerialExportStringRequest.FromString,
                    response_serializer=gpio__pb2.SerialExportStringResponse.SerializeToString,
            ),
            'serialReadByte': grpc.unary_unary_rpc_method_handler(
                    servicer.serialReadByte,
                    request_deserializer=gpio__pb2.SerialReadByteRequest.FromString,
                    response_serializer=gpio__pb2.SerialReadByteResponse.SerializeToString,
            ),
            'serialReadString': grpc.unary_unary_rpc_method_handler(
                    servicer.serialReadString,
                    request_deserializer=gpio__pb2.SerialReadStringRequest.FromString,
                    response_serializer=gpio__pb2.SerialReadStringResponse.SerializeToString,
            ),
            'serialReadUtil': grpc.unary_unary_rpc_method_handler(
                    servicer.serialReadUtil,
                    request_deserializer=gpio__pb2.SerialReadUtilRequest.FromString,
                    response_serializer=gpio__pb2.SerialReadUtilResponse.SerializeToString,
            ),
            'clearAllGpioAndSerial': grpc.unary_unary_rpc_method_handler(
                    servicer.clearAllGpioAndSerial,
                    request_deserializer=gpio__pb2.ClearAllGpioAndSerialRequest.FromString,
                    response_serializer=gpio__pb2.ClearAllGpioAndSerialResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'GpioPackage.GpioServiceGrpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GpioServiceGrpc(object):
    """

    一: gpio 引脚对应，传值的时候转换一下

    1  146 
    2  147
    3  149 (此接口当前是 USB 供电口，不可用)
    4  150
    5  151
    6  131

    二: 引脚 PWM 输出

    frequency: 频率赫兹
    duty_cycle: slider 的值，范围（0 ～ 255）
    range: 范围，根据需求填 255

    三: 串口，开放接口上的串口默认值为：

    /dev/ttyS0

    四：串口写字符换行功能

    只要在字符串后面添加 \r\n 就能实现换行


    定义服务,用在rpc传输中
    """

    @staticmethod
    def setGpioExport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/setGpioExport',
            gpio__pb2.SetGpioExportRequest.SerializeToString,
            gpio__pb2.SetGpioExportResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def readGpio(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/readGpio',
            gpio__pb2.ReadGpioRequest.SerializeToString,
            gpio__pb2.ReadGpioResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setGpioStartExportPwm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/setGpioStartExportPwm',
            gpio__pb2.SetGpioStartExportPwmRequest.SerializeToString,
            gpio__pb2.SetGpioStartExportPwmResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setGpioStopExportPwm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/setGpioStopExportPwm',
            gpio__pb2.SetGpioStopExportPwmRequest.SerializeToString,
            gpio__pb2.SetGpioStopExportPwmResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def setSerbaud(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/setSerbaud',
            gpio__pb2.SetSerbaudRequest.SerializeToString,
            gpio__pb2.SetSerbaudResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def serialExportString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/serialExportString',
            gpio__pb2.SerialExportStringRequest.SerializeToString,
            gpio__pb2.SerialExportStringResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def serialReadByte(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/serialReadByte',
            gpio__pb2.SerialReadByteRequest.SerializeToString,
            gpio__pb2.SerialReadByteResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def serialReadString(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/serialReadString',
            gpio__pb2.SerialReadStringRequest.SerializeToString,
            gpio__pb2.SerialReadStringResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def serialReadUtil(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/serialReadUtil',
            gpio__pb2.SerialReadUtilRequest.SerializeToString,
            gpio__pb2.SerialReadUtilResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def clearAllGpioAndSerial(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/GpioPackage.GpioServiceGrpc/clearAllGpioAndSerial',
            gpio__pb2.ClearAllGpioAndSerialRequest.SerializeToString,
            gpio__pb2.ClearAllGpioAndSerialResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: vision.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cvision.proto\x12\x0f\x41IVisionPackage\"7\n\x10TrainAndSavePara\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rcategoryNames\x18\x02 \x03(\t\"U\n\x13TrainAndSaveRequest\x12\r\n\x05model\x18\x01 \x01(\t\x12/\n\x04para\x18\x02 \x01(\x0b\x32!.AIVisionPackage.TrainAndSavePara\"?\n\x14TrainAndSaveResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\".\n\x0fLoadModelInfoIn\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0c\n\x04para\x18\x02 \x01(\t\"D\n\x10LoadModelRequest\x12\x30\n\x06models\x18\x01 \x03(\x0b\x32 .AIVisionPackage.LoadModelInfoIn\"<\n\x11LoadModelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"B\n\x13SetModelParaRequest\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0e\n\x06invoke\x18\x02 \x01(\t\x12\x0c\n\x04para\x18\x03 \x01(\t\"?\n\x14SetModelParaResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"/\n\x10InferenceModelIn\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0c\n\x04para\x18\x02 \x01(\t\"W\n\x10InferenceRequest\x12\x10\n\x08need_pic\x18\x01 \x01(\x08\x12\x31\n\x06models\x18\x02 \x03(\x0b\x32!.AIVisionPackage.InferenceModelIn\"0\n\x11InferenceModelOut\x12\r\n\x05model\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\t\"S\n\rInferenceData\x12\x0b\n\x03img\x18\x01 \x01(\t\x12\x35\n\tinference\x18\x02 \x03(\x0b\x32\".AIVisionPackage.InferenceModelOut\"\\\n\x11InferenceResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12,\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1e.AIVisionPackage.InferenceData\"%\n\x13ReleaseModelRequest\x12\x0e\n\x06models\x18\x01 \x03(\t\"?\n\x14ReleaseModelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\"&\n\x14\x41utoInferenceRequest\x12\x0e\n\x06models\x18\x01 \x03(\t\"B\n\x14\x43\x61meraNumberResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x65v_num\x18\x03 \x01(\x05\"\x0e\n\x0c\x45mptyRequest\"+\n\x0e\x43ommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xbe\x07\n\x13\x41IVisionServiceGrpc\x12_\n\x0ctrainAndSave\x12$.AIVisionPackage.TrainAndSaveRequest\x1a%.AIVisionPackage.TrainAndSaveResponse\"\x00\x30\x01\x12T\n\tloadModel\x12!.AIVisionPackage.LoadModelRequest\x1a\".AIVisionPackage.LoadModelResponse\"\x00\x12]\n\x0csetModelPara\x12$.AIVisionPackage.SetModelParaRequest\x1a%.AIVisionPackage.SetModelParaResponse\"\x00\x12[\n\x10\x64oModelInference\x12!.AIVisionPackage.InferenceRequest\x1a\".AIVisionPackage.InferenceResponse\"\x00\x12]\n\x0creleaseModel\x12$.AIVisionPackage.ReleaseModelRequest\x1a%.AIVisionPackage.ReleaseModelResponse\"\x00\x12\x63\n\x12startAutoInference\x12%.AIVisionPackage.AutoInferenceRequest\x1a\".AIVisionPackage.InferenceResponse\"\x00\x30\x01\x12U\n\x11stopAutoInference\x12\x1d.AIVisionPackage.EmptyRequest\x1a\x1f.AIVisionPackage.CommonResponse\"\x00\x12\x61\n\x18startPushInferenceResult\x12\x1d.AIVisionPackage.EmptyRequest\x1a\".AIVisionPackage.InferenceResponse\"\x00\x30\x01\x12[\n\x17stopPushInferenceResult\x12\x1d.AIVisionPackage.EmptyRequest\x1a\x1f.AIVisionPackage.CommonResponse\"\x00\x12Y\n\x0fgetCameraNumber\x12\x1d.AIVisionPackage.EmptyRequest\x1a%.AIVisionPackage.CameraNumberResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'vision_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRAINANDSAVEPARA._serialized_start=33
  _TRAINANDSAVEPARA._serialized_end=88
  _TRAINANDSAVEREQUEST._serialized_start=90
  _TRAINANDSAVEREQUEST._serialized_end=175
  _TRAINANDSAVERESPONSE._serialized_start=177
  _TRAINANDSAVERESPONSE._serialized_end=240
  _LOADMODELINFOIN._serialized_start=242
  _LOADMODELINFOIN._serialized_end=288
  _LOADMODELREQUEST._serialized_start=290
  _LOADMODELREQUEST._serialized_end=358
  _LOADMODELRESPONSE._serialized_start=360
  _LOADMODELRESPONSE._serialized_end=420
  _SETMODELPARAREQUEST._serialized_start=422
  _SETMODELPARAREQUEST._serialized_end=488
  _SETMODELPARARESPONSE._serialized_start=490
  _SETMODELPARARESPONSE._serialized_end=553
  _INFERENCEMODELIN._serialized_start=555
  _INFERENCEMODELIN._serialized_end=602
  _INFERENCEREQUEST._serialized_start=604
  _INFERENCEREQUEST._serialized_end=691
  _INFERENCEMODELOUT._serialized_start=693
  _INFERENCEMODELOUT._serialized_end=741
  _INFERENCEDATA._serialized_start=743
  _INFERENCEDATA._serialized_end=826
  _INFERENCERESPONSE._serialized_start=828
  _INFERENCERESPONSE._serialized_end=920
  _RELEASEMODELREQUEST._serialized_start=922
  _RELEASEMODELREQUEST._serialized_end=959
  _RELEASEMODELRESPONSE._serialized_start=961
  _RELEASEMODELRESPONSE._serialized_end=1024
  _AUTOINFERENCEREQUEST._serialized_start=1026
  _AUTOINFERENCEREQUEST._serialized_end=1064
  _CAMERANUMBERRESPONSE._serialized_start=1066
  _CAMERANUMBERRESPONSE._serialized_end=1132
  _EMPTYREQUEST._serialized_start=1134
  _EMPTYREQUEST._serialized_end=1148
  _COMMONRESPONSE._serialized_start=1150
  _COMMONRESPONSE._serialized_end=1193
  _AIVISIONSERVICEGRPC._serialized_start=1196
  _AIVISIONSERVICEGRPC._serialized_end=2154
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: device.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x64\x65vice.proto\x12\rDevicePackage\"B\n\x12LightEffectRequest\x12\x0e\n\x06\x65\x66\x66\x65\x63t\x18\x01 \x01(\x05\x12\r\n\x05level\x18\x02 \x01(\x05\x12\r\n\x05\x63olor\x18\x03 \x01(\r\"c\n\x11LightColorRequest\x12\x11\n\ttop_light\x18\x01 \x01(\x05\x12\x12\n\nleft_light\x18\x02 \x01(\x05\x12\x13\n\x0bright_light\x18\x03 \x01(\x05\x12\x12\n\ndown_light\x18\x04 \x01(\x05\"%\n\x13TurnOffLightRequest\x12\x0e\n\x06lights\x18\x01 \x03(\x05\"*\n\rLightResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x13\n\x11\x44\x65viceListRequest\"N\n\nDeviceInfo\x12\x10\n\x08\x64\x65viceId\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x10\n\x08\x66irmware\x18\x03 \x01(\t\x12\x0e\n\x06serial\x18\x04 \x01(\t\"@\n\x0e\x44\x65viceListInfo\x12.\n\x0b\x64\x65vice_list\x18\x01 \x03(\x0b\x32\x19.DevicePackage.DeviceInfo\"\xb6\x01\n\x12\x44\x65viceListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x39\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32+.DevicePackage.DeviceListResponse.DataEntry\x1aJ\n\tDataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12,\n\x05value\x18\x02 \x01(\x0b\x32\x1d.DevicePackage.DeviceListInfo:\x02\x38\x01\"\x13\n\x11\x44\x65viceNameRequest\"=\n\x12\x44\x65viceNameResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"W\n\x0f\x44isplayTextInfo\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\x11\n\tfont_size\x18\x02 \x01(\x05\x12\x12\n\nfont_color\x18\x03 \x01(\t\x12\x0f\n\x07newline\x18\x04 \x01(\x08\"\x80\x01\n\x10\x44isplayUIRequest\x12\x18\n\x10\x62\x61\x63kground_color\x18\x01 \x01(\t\x12\x10\n\x08img_name\x18\x02 \x01(\t\x12\x31\n\ttext_list\x18\x03 \x03(\x0b\x32\x1e.DevicePackage.DisplayTextInfo\x12\r\n\x05reset\x18\x04 \x01(\x08\"\x1b\n\x19\x44isplayPictureListRequest\".\n\x11\x44isplayUIResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"J\n\x1a\x44isplayPictureListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x11\n\tname_list\x18\x03 \x03(\t\"/\n\x1b\x44\x65leteDisplayPictureRequest\x12\x10\n\x08img_name\x18\x01 \x01(\t\"\'\n\x14SetBrightnessRequest\x12\x0f\n\x07percent\x18\x01 \x01(\x05\"\x16\n\x14GetBrightnessRequest\"@\n\x12\x42rightnessResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0f\n\x07percent\x18\x03 \x01(\x05\"\x13\n\x11MacAddressRequest\"<\n\x12MacAddressResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0b\n\x03mac\x18\x03 \x01(\t\"2\n\x10SetVolumeRequest\x12\x0e\n\x06volume\x18\x01 \x01(\x05\x12\x0e\n\x06stream\x18\x02 \x01(\x05\"\x12\n\x10GetVolumeRequest\"K\n\x0eVolumeResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0e\n\x06volume\x18\x03 \x01(\x05\x12\x0e\n\x06isMute\x18\x04 \x01(\x08\"!\n\x11MuteVolumeRequest\x12\x0c\n\x04mute\x18\x01 \x01(\x08\"2\n\x12SelectModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x01(\t\"0\n\x13SelectModelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x14\n\x12\x44\x65viceModelRequest\">\n\x13\x44\x65viceModelResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"L\n\x15\x44\x65viceVersionResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x18\n\x10software_version\x18\x03 \x01(\t\"\x15\n\x13\x44\x65viceCommonRequest\"1\n\x14\x44\x65viceCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xe0\r\n\x11\x44\x65viceServiceGrpc\x12V\n\rgetDeviceList\x12 .DevicePackage.DeviceListRequest\x1a!.DevicePackage.DeviceListResponse\"\x00\x12h\n\x1dstartDeviceListChangeListener\x12 .DevicePackage.DeviceListRequest\x1a!.DevicePackage.DeviceListResponse\"\x00\x30\x01\x12g\n\x1cstopDeviceListChangeListener\x12 .DevicePackage.DeviceListRequest\x1a#.DevicePackage.DeviceCommonResponse\"\x00\x12S\n\x0csetDisplayUI\x12\x1f.DevicePackage.DisplayUIRequest\x1a .DevicePackage.DisplayUIResponse\"\x00\x12n\n\x15getDisplayPictureList\x12(.DevicePackage.DisplayPictureListRequest\x1a).DevicePackage.DisplayPictureListResponse\"\x00\x12i\n\x14\x64\x65leteDisplayPicture\x12*.DevicePackage.DeleteDisplayPictureRequest\x1a#.DevicePackage.DeviceCommonResponse\"\x00\x12Z\n\rstopDisplayUI\x12\".DevicePackage.DeviceCommonRequest\x1a#.DevicePackage.DeviceCommonResponse\"\x00\x12Y\n\rsetBrightness\x12#.DevicePackage.SetBrightnessRequest\x1a!.DevicePackage.BrightnessResponse\"\x00\x12Y\n\rgetBrightness\x12#.DevicePackage.GetBrightnessRequest\x1a!.DevicePackage.BrightnessResponse\"\x00\x12V\n\rgetMacAddress\x12 .DevicePackage.MacAddressRequest\x1a!.DevicePackage.MacAddressResponse\"\x00\x12M\n\tsetVolume\x12\x1f.DevicePackage.SetVolumeRequest\x1a\x1d.DevicePackage.VolumeResponse\"\x00\x12M\n\tgetVolume\x12\x1f.DevicePackage.GetVolumeRequest\x1a\x1d.DevicePackage.VolumeResponse\"\x00\x12O\n\nmuteVolume\x12 .DevicePackage.MuteVolumeRequest\x1a\x1d.DevicePackage.VolumeResponse\"\x00\x12V\n\x0bselectModel\x12!.DevicePackage.SelectModelRequest\x1a\".DevicePackage.SelectModelResponse\"\x00\x12Y\n\x0egetDeviceModel\x12!.DevicePackage.DeviceModelRequest\x1a\".DevicePackage.DeviceModelResponse\"\x00\x12\x66\n\x18getDeviceSoftwareVersion\x12\".DevicePackage.DeviceCommonRequest\x1a$.DevicePackage.DeviceVersionResponse\"\x00\x12T\n\x0fshowLightEffect\x12!.DevicePackage.LightEffectRequest\x1a\x1c.DevicePackage.LightResponse\"\x00\x12R\n\x0eshowLightColor\x12 .DevicePackage.LightColorRequest\x1a\x1c.DevicePackage.LightResponse\"\x00\x12R\n\x0cturnOffLight\x12\".DevicePackage.TurnOffLightRequest\x1a\x1c.DevicePackage.LightResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'device_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DEVICELISTRESPONSE_DATAENTRY._options = None
  _DEVICELISTRESPONSE_DATAENTRY._serialized_options = b'8\001'
  _LIGHTEFFECTREQUEST._serialized_start=31
  _LIGHTEFFECTREQUEST._serialized_end=97
  _LIGHTCOLORREQUEST._serialized_start=99
  _LIGHTCOLORREQUEST._serialized_end=198
  _TURNOFFLIGHTREQUEST._serialized_start=200
  _TURNOFFLIGHTREQUEST._serialized_end=237
  _LIGHTRESPONSE._serialized_start=239
  _LIGHTRESPONSE._serialized_end=281
  _DEVICELISTREQUEST._serialized_start=283
  _DEVICELISTREQUEST._serialized_end=302
  _DEVICEINFO._serialized_start=304
  _DEVICEINFO._serialized_end=382
  _DEVICELISTINFO._serialized_start=384
  _DEVICELISTINFO._serialized_end=448
  _DEVICELISTRESPONSE._serialized_start=451
  _DEVICELISTRESPONSE._serialized_end=633
  _DEVICELISTRESPONSE_DATAENTRY._serialized_start=559
  _DEVICELISTRESPONSE_DATAENTRY._serialized_end=633
  _DEVICENAMEREQUEST._serialized_start=635
  _DEVICENAMEREQUEST._serialized_end=654
  _DEVICENAMERESPONSE._serialized_start=656
  _DEVICENAMERESPONSE._serialized_end=717
  _DISPLAYTEXTINFO._serialized_start=719
  _DISPLAYTEXTINFO._serialized_end=806
  _DISPLAYUIREQUEST._serialized_start=809
  _DISPLAYUIREQUEST._serialized_end=937
  _DISPLAYPICTURELISTREQUEST._serialized_start=939
  _DISPLAYPICTURELISTREQUEST._serialized_end=966
  _DISPLAYUIRESPONSE._serialized_start=968
  _DISPLAYUIRESPONSE._serialized_end=1014
  _DISPLAYPICTURELISTRESPONSE._serialized_start=1016
  _DISPLAYPICTURELISTRESPONSE._serialized_end=1090
  _DELETEDISPLAYPICTUREREQUEST._serialized_start=1092
  _DELETEDISPLAYPICTUREREQUEST._serialized_end=1139
  _SETBRIGHTNESSREQUEST._serialized_start=1141
  _SETBRIGHTNESSREQUEST._serialized_end=1180
  _GETBRIGHTNESSREQUEST._serialized_start=1182
  _GETBRIGHTNESSREQUEST._serialized_end=1204
  _BRIGHTNESSRESPONSE._serialized_start=1206
  _BRIGHTNESSRESPONSE._serialized_end=1270
  _MACADDRESSREQUEST._serialized_start=1272
  _MACADDRESSREQUEST._serialized_end=1291
  _MACADDRESSRESPONSE._serialized_start=1293
  _MACADDRESSRESPONSE._serialized_end=1353
  _SETVOLUMEREQUEST._serialized_start=1355
  _SETVOLUMEREQUEST._serialized_end=1405
  _GETVOLUMEREQUEST._serialized_start=1407
  _GETVOLUMEREQUEST._serialized_end=1425
  _VOLUMERESPONSE._serialized_start=1427
  _VOLUMERESPONSE._serialized_end=1502
  _MUTEVOLUMEREQUEST._serialized_start=1504
  _MUTEVOLUMEREQUEST._serialized_end=1537
  _SELECTMODELREQUEST._serialized_start=1539
  _SELECTMODELREQUEST._serialized_end=1589
  _SELECTMODELRESPONSE._serialized_start=1591
  _SELECTMODELRESPONSE._serialized_end=1639
  _DEVICEMODELREQUEST._serialized_start=1641
  _DEVICEMODELREQUEST._serialized_end=1661
  _DEVICEMODELRESPONSE._serialized_start=1663
  _DEVICEMODELRESPONSE._serialized_end=1725
  _DEVICEVERSIONRESPONSE._serialized_start=1727
  _DEVICEVERSIONRESPONSE._serialized_end=1803
  _DEVICECOMMONREQUEST._serialized_start=1805
  _DEVICECOMMONREQUEST._serialized_end=1826
  _DEVICECOMMONRESPONSE._serialized_start=1828
  _DEVICECOMMONRESPONSE._serialized_end=1877
  _DEVICESERVICEGRPC._serialized_start=1880
  _DEVICESERVICEGRPC._serialized_end=3640
# @@protoc_insertion_point(module_scope)



from zeroconf import ServiceBrowser, ServiceListener, Zeroconf
import socket
import time

DEV_LIST = {}

class DeviceListener(ServiceListener):
    def __init__(self):
        #设备名称+IP列表
        self.device_info = {}
    def update_service(self, zc: Zeroconf, type_: str, name: str) -> None:
        #print(f"Service {name} updated")
        pass
    def remove_service(self, zc: Zeroconf, type_: str, name: str) -> None:
        #print(f"Service {name} removed")
        pass
    def add_service(self, zc: Zeroconf, type_: str, name: str) -> None:
        global DEV_LIST
        info = zc.get_service_info(type_, name)
        #print(f"Service {name} added, service info: {info}")
        if info:
            device_name = info.name.split(".")[0].split(":")
            result_name = "UGOT_" + device_name[-2] + device_name[-1]
            #print("device_name : ",result_name)
            if len(info.addresses)>0:
                #print("ip: ",  socket.inet_ntoa(info.addresses[0]))
                device_ip = socket.inet_ntoa(info.addresses[0])
                self.device_info[result_name] = device_ip
                DEV_LIST[result_name] = device_ip

class DeviceScan:
    def __init__(self):
        self.listener = DeviceListener()
        self.device_name_list=[]
        self.device_info_list={}
    def device_discovery(self):
        zeroconf = Zeroconf()
        #当连接wifi的时候服务名不带usb
        browser = ServiceBrowser(zeroconf, "_uExplore_channel_server._tcp.local.", self.listener)
        #当连接usb调试线时候服务名带usb
        browser = ServiceBrowser(zeroconf, "_uExplore_channel_server_usb._tcp.local.", self.listener)
        time.sleep(3)
        zeroconf.close()
    def get_device_info_list(self):
        self.device_info_list = self.listener.device_info
        return self.device_info_list
    def get_device_name_list(self):
        for key in self.listener.device_info:
            self.device_name_list.append(key)
        return self.device_name_list
    def get_device_ip_by_name(self,name):
        device_info = self.get_device_info_list()
        for key in device_info:
            if key == name:
                return device_info[key]
        return ""


    



from setuptools import setup, find_packages, find_namespace_packages

setup(
    name = "ugot",
    version = "0.1.4",
    description = "ugot-Python SDK",
    long_description = "",

    packages = find_packages(include=["ugot","ugot.*"]),
    # package_data = {"ugot": ["*"],
    #                 },
    # packages=find_packages(),
    # include_package_data = True,
    platforms = "any",
    install_requires = [
        'concurrent-log-handler',
        'grpcio',
        'protobuf',
        'grpcio-tools',
        'wheel',
        'zeroconf',
    ]
)


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: power.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bpower.proto\x12\x0cPowerPackage\"\x0e\n\x0cPowerRequest\"x\n\x0ePowerValueInfo\x12\r\n\x05level\x18\x01 \x01(\x05\x12\r\n\x05scale\x18\x02 \x01(\x05\x12\x13\n\x0btemperature\x18\x03 \x01(\x02\x12\x0f\n\x07voltage\x18\x04 \x01(\x02\x12\x12\n\npower_plug\x18\x05 \x01(\x08\x12\x0e\n\x06status\x18\x06 \x01(\x05\"[\n\x12PowerValueResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1c.PowerPackage.PowerValueInfo\"0\n\x13PowerCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\x91\x02\n\x10PowerServiceGrpc\x12O\n\rgetPowerValue\x12\x1a.PowerPackage.PowerRequest\x1a .PowerPackage.PowerValueResponse\"\x00\x12V\n\x12startPowerListener\x12\x1a.PowerPackage.PowerRequest\x1a .PowerPackage.PowerValueResponse\"\x00\x30\x01\x12T\n\x11stopPowerListener\x12\x1a.PowerPackage.PowerRequest\x1a!.PowerPackage.PowerCommonResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'power_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _POWERREQUEST._serialized_start=29
  _POWERREQUEST._serialized_end=43
  _POWERVALUEINFO._serialized_start=45
  _POWERVALUEINFO._serialized_end=165
  _POWERVALUERESPONSE._serialized_start=167
  _POWERVALUERESPONSE._serialized_end=258
  _POWERCOMMONRESPONSE._serialized_start=260
  _POWERCOMMONRESPONSE._serialized_end=308
  _POWERSERVICEGRPC._serialized_start=311
  _POWERSERVICEGRPC._serialized_end=584
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

import sensor_pb2 as sensor__pb2


class SensorServiceGrpcStub(object):
    """定义服务,用在rpc传输中
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getDistanceSensorValue = channel.unary_unary(
                '/SensorPackage.SensorServiceGrpc/getDistanceSensorValue',
                request_serializer=sensor__pb2.DistanceSensorRequest.SerializeToString,
                response_deserializer=sensor__pb2.DistanceSensorResponse.FromString,
                )
        self.startDistanceSensorStream = channel.unary_stream(
                '/SensorPackage.SensorServiceGrpc/startDistanceSensorStream',
                request_serializer=sensor__pb2.DistanceSensorRequest.SerializeToString,
                response_deserializer=sensor__pb2.DistanceSensorResponse.FromString,
                )
        self.stopDistanceSensorStream = channel.unary_unary(
                '/SensorPackage.SensorServiceGrpc/stopDistanceSensorStream',
                request_serializer=sensor__pb2.DistanceSensorRequest.SerializeToString,
                response_deserializer=sensor__pb2.SensorCommonResponse.FromString,
                )
        self.getIMUSensorValue = channel.unary_unary(
                '/SensorPackage.SensorServiceGrpc/getIMUSensorValue',
                request_serializer=sensor__pb2.SensorCommonRequest.SerializeToString,
                response_deserializer=sensor__pb2.IMUSensorResponse.FromString,
                )
        self.startCalibrate = channel.unary_stream(
                '/SensorPackage.SensorServiceGrpc/startCalibrate',
                request_serializer=sensor__pb2.StartCalibrateRequest.SerializeToString,
                response_deserializer=sensor__pb2.StartCalibrateResponse.FromString,
                )
        self.cancelCalibrate = channel.unary_unary(
                '/SensorPackage.SensorServiceGrpc/cancelCalibrate',
                request_serializer=sensor__pb2.CancelCalibrateRequest.SerializeToString,
                response_deserializer=sensor__pb2.CancelCalibrateResponse.FromString,
                )
        self.getAttitudeTilt = channel.unary_unary(
                '/SensorPackage.SensorServiceGrpc/getAttitudeTilt',
                request_serializer=sensor__pb2.AttitudeTiltRequest.SerializeToString,
                response_deserializer=sensor__pb2.AttitudeTiltResponse.FromString,
                )
        self.calibrateIMUWithAVFeedback = channel.unary_stream(
                '/SensorPackage.SensorServiceGrpc/calibrateIMUWithAVFeedback',
                request_serializer=sensor__pb2.StartCalibrateRequest.SerializeToString,
                response_deserializer=sensor__pb2.StartCalibrateResponse.FromString,
                )


class SensorServiceGrpcServicer(object):
    """定义服务,用在rpc传输中
    """

    def getDistanceSensorValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startDistanceSensorStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stopDistanceSensorStream(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getIMUSensorValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def startCalibrate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def cancelCalibrate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAttitudeTilt(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def calibrateIMUWithAVFeedback(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SensorServiceGrpcServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getDistanceSensorValue': grpc.unary_unary_rpc_method_handler(
                    servicer.getDistanceSensorValue,
                    request_deserializer=sensor__pb2.DistanceSensorRequest.FromString,
                    response_serializer=sensor__pb2.DistanceSensorResponse.SerializeToString,
            ),
            'startDistanceSensorStream': grpc.unary_stream_rpc_method_handler(
                    servicer.startDistanceSensorStream,
                    request_deserializer=sensor__pb2.DistanceSensorRequest.FromString,
                    response_serializer=sensor__pb2.DistanceSensorResponse.SerializeToString,
            ),
            'stopDistanceSensorStream': grpc.unary_unary_rpc_method_handler(
                    servicer.stopDistanceSensorStream,
                    request_deserializer=sensor__pb2.DistanceSensorRequest.FromString,
                    response_serializer=sensor__pb2.SensorCommonResponse.SerializeToString,
            ),
            'getIMUSensorValue': grpc.unary_unary_rpc_method_handler(
                    servicer.getIMUSensorValue,
                    request_deserializer=sensor__pb2.SensorCommonRequest.FromString,
                    response_serializer=sensor__pb2.IMUSensorResponse.SerializeToString,
            ),
            'startCalibrate': grpc.unary_stream_rpc_method_handler(
                    servicer.startCalibrate,
                    request_deserializer=sensor__pb2.StartCalibrateRequest.FromString,
                    response_serializer=sensor__pb2.StartCalibrateResponse.SerializeToString,
            ),
            'cancelCalibrate': grpc.unary_unary_rpc_method_handler(
                    servicer.cancelCalibrate,
                    request_deserializer=sensor__pb2.CancelCalibrateRequest.FromString,
                    response_serializer=sensor__pb2.CancelCalibrateResponse.SerializeToString,
            ),
            'getAttitudeTilt': grpc.unary_unary_rpc_method_handler(
                    servicer.getAttitudeTilt,
                    request_deserializer=sensor__pb2.AttitudeTiltRequest.FromString,
                    response_serializer=sensor__pb2.AttitudeTiltResponse.SerializeToString,
            ),
            'calibrateIMUWithAVFeedback': grpc.unary_stream_rpc_method_handler(
                    servicer.calibrateIMUWithAVFeedback,
                    request_deserializer=sensor__pb2.StartCalibrateRequest.FromString,
                    response_serializer=sensor__pb2.StartCalibrateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'SensorPackage.SensorServiceGrpc', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SensorServiceGrpc(object):
    """定义服务,用在rpc传输中
    """

    @staticmethod
    def getDistanceSensorValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/SensorPackage.SensorServiceGrpc/getDistanceSensorValue',
            sensor__pb2.DistanceSensorRequest.SerializeToString,
            sensor__pb2.DistanceSensorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startDistanceSensorStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/SensorPackage.SensorServiceGrpc/startDistanceSensorStream',
            sensor__pb2.DistanceSensorRequest.SerializeToString,
            sensor__pb2.DistanceSensorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stopDistanceSensorStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/SensorPackage.SensorServiceGrpc/stopDistanceSensorStream',
            sensor__pb2.DistanceSensorRequest.SerializeToString,
            sensor__pb2.SensorCommonResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getIMUSensorValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/SensorPackage.SensorServiceGrpc/getIMUSensorValue',
            sensor__pb2.SensorCommonRequest.SerializeToString,
            sensor__pb2.IMUSensorResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def startCalibrate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/SensorPackage.SensorServiceGrpc/startCalibrate',
            sensor__pb2.StartCalibrateRequest.SerializeToString,
            sensor__pb2.StartCalibrateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def cancelCalibrate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/SensorPackage.SensorServiceGrpc/cancelCalibrate',
            sensor__pb2.CancelCalibrateRequest.SerializeToString,
            sensor__pb2.CancelCalibrateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def getAttitudeTilt(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/SensorPackage.SensorServiceGrpc/getAttitudeTilt',
            sensor__pb2.AttitudeTiltRequest.SerializeToString,
            sensor__pb2.AttitudeTiltResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def calibrateIMUWithAVFeedback(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/SensorPackage.SensorServiceGrpc/calibrateIMUWithAVFeedback',
            sensor__pb2.StartCalibrateRequest.SerializeToString,
            sensor__pb2.StartCalibrateResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import grpc
class GrpcClient:
    def __init__(self, address):
        # 舵机
        self.address = address
        # self._address = '0.0.0.0:50051'
        self._channel = None

    @property
    def channel(self):
        self._channel = grpc.insecure_channel(self.address)

        return self._channel

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, __address):
        if not len(__address):
            return
        self._address = __address




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bluetooth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x62luetooth.proto\x12\x10\x42luetoothPackage\"\\\n\x08\x42tDevice\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12\r\n\x05\x63lass\x18\x03 \x01(\t\x12\x0c\n\x04rssi\x18\x04 \x01(\x05\x12\x14\n\x0cis_connected\x18\x05 \x01(\x08\"!\n\x0f\x42tEnableRequest\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x05\"-\n\x10\x42tEnableResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x11\n\x0f\x42tStatusRequest\"\x83\x01\n\x10\x42tStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0f\n\x07poweron\x18\x03 \x01(\x08\x12\x11\n\tconnected\x18\x04 \x01(\x08\x12\x30\n\x0cremoteDevice\x18\x05 \x01(\x0b\x32\x1a.BluetoothPackage.BtDevice\"\x1c\n\x1a\x42tFoundedDeviceListRequest\"\x9a\x01\n\x1b\x42tFoundedDeviceListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12/\n\x0bscaned_list\x18\x03 \x03(\x0b\x32\x1a.BluetoothPackage.BtDevice\x12/\n\x0bpaired_list\x18\x04 \x03(\x0b\x32\x1a.BluetoothPackage.BtDevice\"\x17\n\x15StartDiscoveryRequest\"_\n\x16StartDiscoveryResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x06\x64\x65vice\x18\x03 \x01(\x0b\x32\x1a.BluetoothPackage.BtDevice\"\x18\n\x16\x43\x61ncelDiscoveryRequest\"4\n\x17\x43\x61ncelDiscoveryResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x14\n\x12IsDiscoveryRequest\"E\n\x13IsDiscoveryResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x13\n\x0bis_dicovery\x18\x03 \x01(\x08\"\x15\n\x13\x42tDisconnectRequest\"1\n\x14\x42tDisconnectResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\" \n\rBtPairRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"+\n\x0e\x42tPairResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\"\n\x0f\x42tUnpairRequest\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\"-\n\x10\x42tUnpairResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"\x16\n\x14\x42tStateListenRequest\"2\n\x15\x42tStateListenResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t2\xc1\x08\n\x14\x42luetoothServiceGrpc\x12T\n\tsetEnable\x12!.BluetoothPackage.BtEnableRequest\x1a\".BluetoothPackage.BtEnableResponse\"\x00\x12V\n\x0bgetBtStatus\x12!.BluetoothPackage.BtStatusRequest\x1a\".BluetoothPackage.BtStatusResponse\"\x00\x12\x64\n\x12startBtStateListen\x12&.BluetoothPackage.BtStateListenRequest\x1a\".BluetoothPackage.BtStatusResponse\"\x00\x30\x01\x12\x66\n\x11stopBtStateListen\x12&.BluetoothPackage.BtStateListenRequest\x1a\'.BluetoothPackage.BtStateListenResponse\"\x00\x12g\n\x0estartDiscovery\x12\'.BluetoothPackage.StartDiscoveryRequest\x1a(.BluetoothPackage.StartDiscoveryResponse\"\x00\x30\x01\x12h\n\x0f\x63\x61ncelDiscovery\x12(.BluetoothPackage.CancelDiscoveryRequest\x1a).BluetoothPackage.CancelDiscoveryResponse\"\x00\x12\\\n\x0bisDiscovery\x12$.BluetoothPackage.IsDiscoveryRequest\x1a%.BluetoothPackage.IsDiscoveryResponse\"\x00\x12w\n\x16getBtFoundedDeviceList\x12,.BluetoothPackage.BtFoundedDeviceListRequest\x1a-.BluetoothPackage.BtFoundedDeviceListResponse\"\x00\x12_\n\x0c\x64isconnectBt\x12%.BluetoothPackage.BtDisconnectRequest\x1a&.BluetoothPackage.BtDisconnectResponse\"\x00\x12M\n\x06pairBt\x12\x1f.BluetoothPackage.BtPairRequest\x1a .BluetoothPackage.BtPairResponse\"\x00\x12S\n\x08unpairBt\x12!.BluetoothPackage.BtUnpairRequest\x1a\".BluetoothPackage.BtUnpairResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bluetooth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _BTDEVICE._serialized_start=37
  _BTDEVICE._serialized_end=129
  _BTENABLEREQUEST._serialized_start=131
  _BTENABLEREQUEST._serialized_end=164
  _BTENABLERESPONSE._serialized_start=166
  _BTENABLERESPONSE._serialized_end=211
  _BTSTATUSREQUEST._serialized_start=213
  _BTSTATUSREQUEST._serialized_end=230
  _BTSTATUSRESPONSE._serialized_start=233
  _BTSTATUSRESPONSE._serialized_end=364
  _BTFOUNDEDDEVICELISTREQUEST._serialized_start=366
  _BTFOUNDEDDEVICELISTREQUEST._serialized_end=394
  _BTFOUNDEDDEVICELISTRESPONSE._serialized_start=397
  _BTFOUNDEDDEVICELISTRESPONSE._serialized_end=551
  _STARTDISCOVERYREQUEST._serialized_start=553
  _STARTDISCOVERYREQUEST._serialized_end=576
  _STARTDISCOVERYRESPONSE._serialized_start=578
  _STARTDISCOVERYRESPONSE._serialized_end=673
  _CANCELDISCOVERYREQUEST._serialized_start=675
  _CANCELDISCOVERYREQUEST._serialized_end=699
  _CANCELDISCOVERYRESPONSE._serialized_start=701
  _CANCELDISCOVERYRESPONSE._serialized_end=753
  _ISDISCOVERYREQUEST._serialized_start=755
  _ISDISCOVERYREQUEST._serialized_end=775
  _ISDISCOVERYRESPONSE._serialized_start=777
  _ISDISCOVERYRESPONSE._serialized_end=846
  _BTDISCONNECTREQUEST._serialized_start=848
  _BTDISCONNECTREQUEST._serialized_end=869
  _BTDISCONNECTRESPONSE._serialized_start=871
  _BTDISCONNECTRESPONSE._serialized_end=920
  _BTPAIRREQUEST._serialized_start=922
  _BTPAIRREQUEST._serialized_end=954
  _BTPAIRRESPONSE._serialized_start=956
  _BTPAIRRESPONSE._serialized_end=999
  _BTUNPAIRREQUEST._serialized_start=1001
  _BTUNPAIRREQUEST._serialized_end=1035
  _BTUNPAIRRESPONSE._serialized_start=1037
  _BTUNPAIRRESPONSE._serialized_end=1082
  _BTSTATELISTENREQUEST._serialized_start=1084
  _BTSTATELISTENREQUEST._serialized_end=1106
  _BTSTATELISTENRESPONSE._serialized_start=1108
  _BTSTATELISTENRESPONSE._serialized_end=1158
  _BLUETOOTHSERVICEGRPC._serialized_start=1161
  _BLUETOOTHSERVICEGRPC._serialized_end=2250
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\rnetwork.proto\x12\x0eNetworkPackage\"\x16\n\x14NetworkCommonRequest\"A\n\x12WifiConnectRequest\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x0e\n\x06passwd\x18\x02 \x01(\t\x12\r\n\x05saved\x18\x03 \x01(\x08\"i\n\x13WifiConnectResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0c\n\x04ssid\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\x05\x12\r\n\x05\x62ssid\x18\x05 \x01(\t\x12\x0b\n\x03\x65xt\x18\x06 \x01(\t\"#\n\x11WifiEnableRequest\x12\x0e\n\x06\x65nable\x18\x01 \x01(\t\"[\n\x0cWifiListInfo\x12\x0c\n\x04ssid\x18\x01 \x01(\t\x12\x0c\n\x04rssi\x18\x02 \x01(\x05\x12\r\n\x05\x62ssid\x18\x03 \x01(\t\x12\x11\n\tfrequency\x18\x04 \x01(\x05\x12\r\n\x05\x66lags\x18\x05 \x01(\t\"T\n\rWifiSavedInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04ssid\x18\x02 \x01(\t\x12\r\n\x05\x62ssid\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0b\n\x03\x65xt\x18\x05 \x01(\t\"\x8b\x01\n\x10WifiListResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12*\n\x04\x64\x61ta\x18\x03 \x03(\x0b\x32\x1c.NetworkPackage.WifiListInfo\x12\x30\n\tsaveDwifi\x18\x04 \x03(\x0b\x32\x1d.NetworkPackage.WifiSavedInfo\"\xe2\x01\n\rWifiStateInfo\x12\x12\n\nip_address\x18\x01 \x01(\t\x12\x0b\n\x03mac\x18\x02 \x01(\t\x12\x0c\n\x04\x66req\x18\x03 \x01(\t\x12\x0c\n\x04ssid\x18\x04 \x01(\t\x12\x0c\n\x04rssi\x18\x05 \x01(\t\x12\r\n\x05state\x18\x06 \x01(\t\x12\x0c\n\x04mode\x18\x07 \x01(\t\x12\x10\n\x08key_mgmt\x18\x08 \x01(\t\x12\x14\n\x0cgroup_cipher\x18\t \x01(\t\x12\x17\n\x0fpairwise_cipher\x18\n \x01(\t\x12\x0c\n\x04uuid\x18\x0b \x01(\t\x12\x1a\n\x12p2p_device_address\x18\x0c \x01(\t\"[\n\x11WifiStateResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12+\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x1d.NetworkPackage.WifiStateInfo\"6\n\x12HotspotInfoRequest\x12\x10\n\x08hot_name\x18\x01 \x01(\t\x12\x0e\n\x06passwd\x18\x02 \x01(\t\"@\n\x14HotspotStateResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\x05\"2\n\x15NetworkCommonResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\"C\n\x16\x42TJoypadStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\")\n\x17SetBrocastEnableRequest\x12\x0e\n\x06\x65nable\x18\x01 \x01(\t\"&\n\x15SetBrocastPortRequest\x12\r\n\x05nPort\x18\x01 \x01(\t\"&\n\x15SendBrocastMsgRequest\x12\r\n\x05stMsg\x18\x01 \x01(\t\"T\n\x1dGetReceivedBrocastMsgResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x18\n\x10received_message\x18\x03 \x01(\t2\xcd\x0b\n\x12NetworkServiceGrpc\x12W\n\x0bgetWifiList\x12$.NetworkPackage.NetworkCommonRequest\x1a .NetworkPackage.WifiListResponse\"\x00\x12Z\n\x0b\x63onnectWifi\x12\".NetworkPackage.WifiConnectRequest\x1a#.NetworkPackage.WifiConnectResponse\"\x00\x30\x01\x12Z\n\rgetWifiStatus\x12$.NetworkPackage.NetworkCommonRequest\x1a!.NetworkPackage.WifiStateResponse\"\x00\x12[\n\rsetWifiEnable\x12!.NetworkPackage.WifiEnableRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12_\n\x0e\x64isconnectWifi\x12$.NetworkPackage.NetworkCommonRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12\x65\n\x16startWifiStateListener\x12$.NetworkPackage.NetworkCommonRequest\x1a!.NetworkPackage.WifiStateResponse\"\x00\x30\x01\x12\x66\n\x15stopWifiStateListener\x12$.NetworkPackage.NetworkCommonRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12[\n\x0cstartHotspot\x12\".NetworkPackage.HotspotInfoRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12\\\n\x0bstopHotspot\x12$.NetworkPackage.NetworkCommonRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12_\n\x0fgetHotspotState\x12$.NetworkPackage.NetworkCommonRequest\x1a$.NetworkPackage.HotspotStateResponse\"\x00\x12\x63\n\x11getBTJoypadStatus\x12$.NetworkPackage.NetworkCommonRequest\x1a&.NetworkPackage.BTJoypadStatusResponse\"\x00\x12\x64\n\x10setBrocastEnable\x12\'.NetworkPackage.SetBrocastEnableRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12`\n\x0esetBrocastPort\x12%.NetworkPackage.SetBrocastPortRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12`\n\x0esendBrocastMsg\x12%.NetworkPackage.SendBrocastMsgRequest\x1a%.NetworkPackage.NetworkCommonResponse\"\x00\x12n\n\x15getReceivedBrocastMsg\x12$.NetworkPackage.NetworkCommonRequest\x1a-.NetworkPackage.GetReceivedBrocastMsgResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'network_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _NETWORKCOMMONREQUEST._serialized_start=33
  _NETWORKCOMMONREQUEST._serialized_end=55
  _WIFICONNECTREQUEST._serialized_start=57
  _WIFICONNECTREQUEST._serialized_end=122
  _WIFICONNECTRESPONSE._serialized_start=124
  _WIFICONNECTRESPONSE._serialized_end=229
  _WIFIENABLEREQUEST._serialized_start=231
  _WIFIENABLEREQUEST._serialized_end=266
  _WIFILISTINFO._serialized_start=268
  _WIFILISTINFO._serialized_end=359
  _WIFISAVEDINFO._serialized_start=361
  _WIFISAVEDINFO._serialized_end=445
  _WIFILISTRESPONSE._serialized_start=448
  _WIFILISTRESPONSE._serialized_end=587
  _WIFISTATEINFO._serialized_start=590
  _WIFISTATEINFO._serialized_end=816
  _WIFISTATERESPONSE._serialized_start=818
  _WIFISTATERESPONSE._serialized_end=909
  _HOTSPOTINFOREQUEST._serialized_start=911
  _HOTSPOTINFOREQUEST._serialized_end=965
  _HOTSPOTSTATERESPONSE._serialized_start=967
  _HOTSPOTSTATERESPONSE._serialized_end=1031
  _NETWORKCOMMONRESPONSE._serialized_start=1033
  _NETWORKCOMMONRESPONSE._serialized_end=1083
  _BTJOYPADSTATUSRESPONSE._serialized_start=1085
  _BTJOYPADSTATUSRESPONSE._serialized_end=1152
  _SETBROCASTENABLEREQUEST._serialized_start=1154
  _SETBROCASTENABLEREQUEST._serialized_end=1195
  _SETBROCASTPORTREQUEST._serialized_start=1197
  _SETBROCASTPORTREQUEST._serialized_end=1235
  _SENDBROCASTMSGREQUEST._serialized_start=1237
  _SENDBROCASTMSGREQUEST._serialized_end=1275
  _GETRECEIVEDBROCASTMSGRESPONSE._serialized_start=1277
  _GETRECEIVEDBROCASTMSGRESPONSE._serialized_end=1361
  _NETWORKSERVICEGRPC._serialized_start=1364
  _NETWORKSERVICEGRPC._serialized_end=2849
# @@protoc_insertion_point(module_scope)



import logging
import sys, os

sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
from ugot.grpc_pb import gpio_pb2, gpio_pb2_grpc
from base_client import GrpcClient

class GpioClient(GrpcClient):
    def __init__(self, address):
        super().__init__(address)

        self.client = gpio_pb2_grpc.GpioServiceGrpcStub(channel=self.channel)

    def setGpioExport(self, pin, value):
        input_data = gpio_pb2.SetGpioExportRequest()
        input_data.pin = pin
        input_data.value = value

        response = self.client.setGpioExport(input_data)
        return response

    def readGpio(self, pin):
        input_data = gpio_pb2.ReadGpioRequest()
        input_data.pin = pin

        response = self.client.readGpio(input_data)
        return response

    def setGpioStartExportPwm(self, pin, duty_cycle):
        input_data = gpio_pb2.SetGpioStartExportPwmRequest()
        input_data.pin = pin
        input_data.frequency = 490  # 频率，默认为490Hz
        input_data.duty_cycle = int(duty_cycle)
        input_data.range = 255  # 范围，目前需求是255
        response = self.client.setGpioStartExportPwm(input_data)
        return response

    def setGpioStopExportPwm(self, pin):
        input_data = gpio_pb2.SetGpioStopExportPwmRequest()
        input_data.pin = pin

        response = self.client.setGpioStopExportPwm(input_data)
        return response

    # serial
    def setSerbaud(self, baudrate, port=''):
        input_data = gpio_pb2.SetSerbaudRequest()
        input_data.port = port
        input_data.baudrate = int(baudrate)

        response = self.client.setSerbaud(input_data)
        return response

    def serialExportString(self, value, port=''):
        input_data = gpio_pb2.SerialExportStringRequest()
        input_data.port = port
        input_data.value = str(value)

        response = self.client.serialExportString(input_data)
        return response

    def serialReadByte(self, port=''):
        input_data = gpio_pb2.SerialReadByteRequest()
        input_data.port = port

        response = self.client.serialReadByte(input_data)
        return response

    def serialReadString(self, port=''):
        input_data = gpio_pb2.SerialReadStringRequest()
        input_data.port = port

        response = self.client.serialReadString(input_data)
        return response

    def serialReadUtil(self, char_, port=''):
        input_data = gpio_pb2.SerialReadUtilRequest()
        input_data.port = port
        input_data.char_ = str(char_)

        response = self.client.serialReadUtil(input_data)
        return response

    def clearAllGpioAndSerial(self):
        input_data = gpio_pb2.ClearAllGpioAndSerialRequest()

        response = self.client.clearAllGpioAndSerial(input_data)
        return response

    def __del__(self):
        # 销毁时候释放串口资源
        try:
            self.clearAllGpioAndSerial()
        except Exception as e:
            print('gpio clearAllGpioAndSerial error:')
        pass


import sys,os
sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
from ugot.grpc_pb import sensor_pb2,sensor_pb2_grpc
from base_client import GrpcClient

class SensorClient(GrpcClient):

    def __init__(self, address):
        super().__init__(address)

        self.client = sensor_pb2_grpc.SensorServiceGrpcStub(channel=self.channel)

    def getDistanceSensorValue(self, sensor_id):
        input_data = sensor_pb2.DistanceSensorRequest()
        input_data.deviceId = str(sensor_id)

        response = self.client.getDistanceSensorValue(input_data)
        if response.code != 0:
            response.data.value = -1
        return response.data

    def getIMUSensorValue(self):
        input_data = sensor_pb2.SensorCommonRequest()

        response = self.client.getIMUSensorValue(input_data)
        return response.data

    def getAttitudeTilt(self):
        # 加速度
        input_data = sensor_pb2.AttitudeTiltRequest()

        response = self.client.getAttitudeTilt(input_data)

        return response


import logging
import sys,os
sys.path.append(os.path.dirname(os.path.realpath(__file__)))
sys.path.append(os.path.dirname(os.path.realpath(__file__)) + '/../grpc_pb/')
import json
from ugot.grpc_pb import vision_pb2,vision_pb2_grpc
from base_client import GrpcClient

# AI视觉
MODELNAME_KNN = 'custom_knn' # knn
MODELNAME_POSE = 'human_pose' # 人体姿态
MODELNAME_WORD = 'word_recognition' # 文字识别
MODELNAME_COLOR = 'color_recognition' # 颜色识别
MODELNAME_APRILTAG = 'apriltag_qrcode' # ArpilTag
MODELNAME_QRCODE = 'apriltag_qrcode' # 二维码
MODELNAME_EXPRESSION = 'face_attribute' # 表情识别
MODELNAME_CHARACTERISTIC = 'face_attribute' # 人脸特征
MODELNAME_LICENSE_PLATE = 'lpd_recognition' # 车牌识别
MODELNAME_GESTURE = 'gesture' # 手势识别
MODELNAME_TRAFFIC = 'traffic_sign' # 交通识别，交通标识以及斑马线
MODELNAME_OBJECT_RECOGNITION = 'object_recognition' # 物体识别
MODELNAME_FACE_RECOGNITION = 'face_recognition' # 人脸识别
MODELNAME_TRACK_RECOGNITION = 'line_recognition' # 单双轨
MODELNAME_COLOR_TRACK = 'color_tracking' # 自定义颜色

MODEL_REFLECT_LIST = {
    MODELNAME_KNN, # = 0 # knn
    MODELNAME_POSE, # = 1 # 人体姿态
    MODELNAME_WORD, # = 2 # 文字识别
    MODELNAME_COLOR, # = 3 # 颜色识别
    MODELNAME_APRILTAG, # = 4 # ArpilTag
    MODELNAME_QRCODE, # = 5 # 二维码
    MODELNAME_EXPRESSION, # = 6 # 表情识别
    MODELNAME_CHARACTERISTIC, # = 7 # 人脸特征
    MODELNAME_LICENSE_PLATE, # = 8 # 车牌识别
    MODELNAME_GESTURE, # = 9 # 手势识别
    MODELNAME_TRAFFIC, # = 10 # 交通识别，交通标识以及斑马线
    MODELNAME_OBJECT_RECOGNITION, # = 11 # 物体识别
    MODELNAME_FACE_RECOGNITION, # = 12 # 人脸识别
    MODELNAME_TRACK_RECOGNITION, # = 13 # 单双轨
    # MODELNAME_COLOR_TRACK, # = 14 # 自定义颜色
}

class VisionClient(GrpcClient):
    def __init__(self, address):
        super().__init__(address)

        self.client = vision_pb2_grpc.AIVisionServiceGrpcStub(channel=self.channel)

    def load_models(self, models):

        input_data = vision_pb2.LoadModelRequest()
        modellist = []
        if isinstance(models, list):
            for idx in models:
                if idx in MODEL_REFLECT_LIST:
                    modellist.append(idx)
                else:
                    print('unknown model of {}'.format(idx))
        elif isinstance(models, str):
            modellist.append(models)
        else:
            return False

        for model in modellist:
            info = input_data.models.add()
            info.model = model
        response = self.client.loadModel(input_data)

        return response.code == 0

    def release_models(self, models = None):

        if models is None:
            return self.unloadAllModels()


        input_data = vision_pb2.ReleaseModelRequest()
        modellist = []
        if isinstance(models, list):
            for idx in models:
                if idx in MODEL_REFLECT_LIST:
                    modellist.append(idx)
                else:
                    print('unknown model of {}'.format(idx))
        elif isinstance(models, str):
            modellist.append(models)
        else:
            return False

        for model in modellist:
            input_data.models.append(model)
        response = self.client.releaseModel(input_data)

        return response.code == 0

    """ knn
        """

    def knn_identify(self, model_name):
        """推理,在times时间内，用模型model_name识别
           结果是否为label

        Args:
            model_name(string): 模型
        Returns:
        """
        model = MODELNAME_KNN

        self.knn_load(model_name)

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        para = {"model_name": model_name}
        info.para = json.dumps(para)
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    def knn_load(self, model_name):
        model = MODELNAME_KNN
        # 加载模型
        input_data = vision_pb2.LoadModelRequest()
        models = [model]
        for model in models:
            info = input_data.models.add()
            info.model = model
            para = {"model_name": model_name}
            info.para = json.dumps(para)
        response = self.client.loadModel(input_data)

    """ 人体姿态
    """


    def pose_identify(self):
        """人体姿态推理
        Args:

        Returns:
            keypoints
        """
        model = MODELNAME_POSE

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        para = {}
        info.para = json.dumps(para)
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 文字识别
    """


    def word_identify(self):
        """文字识别

        Args:
        Returns:
            文字识别结果
        """
        model = MODELNAME_WORD

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 颜色
    """


    def color_identify(self):
        """颜色识别
        """
        model = MODELNAME_COLOR

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ AprilTag
    """


    def apriltag_inference(self):
        """AprilTag
        """
        model = MODELNAME_APRILTAG

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 二维码
    """


    def qrcode_inference(self):
        """二维码
        """
        model = MODELNAME_QRCODE

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 表情识别
    """


    def expression_inference(self):
        """表情识别
        """
        model = MODELNAME_EXPRESSION

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 人脸特征
    """


    def face_characteristic_inference(self):
        """人脸特征
        """
        model = MODELNAME_CHARACTERISTIC

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 车牌识别
    """


    def license_plate_inference(self):
        """车牌识别
        """
        model = MODELNAME_LICENSE_PLATE

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 手势识别
    """


    def gesture_inference(self):
        """手势识别
        """
        model = MODELNAME_GESTURE

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 交通识别
    """


    def traffic_inference(self):
        """交通识别
        """
        model = MODELNAME_TRAFFIC

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 人脸识别"""
    def face_recognition_inference(self):
        """人脸识别
        """
        model = MODELNAME_FACE_RECOGNITION

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        # para = {"model_name":model_name}
        # info.para = json.dumps(para)
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    """ 单双轨识别"""
    def track_recognition_inference(self):
        """单双轨识别
        """
        model = MODELNAME_TRACK_RECOGNITION

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        # para = {"model_name":model_name}
        # info.para = json.dumps(para)
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None

    def set_track_color_line(self, color, line_type):
        model = MODELNAME_TRACK_RECOGNITION

        input_data = vision_pb2.SetModelParaRequest()
        input_data.model = model
        input_data.invoke = "setTrackingColorAndLineType"
        para = {"color": color, "line_type": line_type}
        input_data.para = json.dumps(para)
        response = self.client.setModelPara(input_data)

    """ 自定义颜色识别"""

    def color_track_inference(self, color_name):
        """自定义颜色识别
        """
        model = MODELNAME_COLOR_TRACK

        input_data = vision_pb2.InferenceRequest()
        input_data.need_pic = False
        info = input_data.models.add()
        info.model = model
        para = {"color_name": color_name}
        info.para = json.dumps(para)
        response = self.client.doModelInference(input_data)
        for item in response.data.inference:
            if item.model == model:
                return item.data
        return None



    def unloadAllModels(self):

        # 释放模型
        input_data = vision_pb2.ReleaseModelRequest()
        # input_data.models.append("")
        response = self.client.releaseModel(input_data)
        return response.code == 0

    def startAutoInference(self, models):
        # 开始自动推理
        input_data = vision_pb2.AutoInferenceRequest()
        input_data.models.append("aaa")
        response = self.client.startAutoInference(input_data)

        for feature in response:  # 流式返回的结果
            yield feature.msg

    def __del__(self):
        # # 销毁时候卸载所有模型
        try:
            self.unloadAllModels()
        except Exception as e:
            print('vision unloadAllModels error:')
        pass
